[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

Bug#681134: marked as done (unblock: gnome-bluetooth/3.4.2-1)



Your message dated Wed, 11 Jul 2012 13:10:44 +0200
with message-id <4FFD5F34.1080206@dogguy.org>
and subject line Re: Bug#681134: unblock: gnome-bluetooth/3.4.2-1
has caused the Debian Bug report #681134,
regarding unblock: gnome-bluetooth/3.4.2-1
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact owner@bugs.debian.org
immediately.)


-- 
681134: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=681134
Debian Bug Tracking System
Contact owner@bugs.debian.org with problems
--- Begin Message ---
Package: release.debian.org
Severity: normal
User: release.debian.org@packages.debian.org
Usertags: unblock

Please unblock package gnome-bluetooth

3.4.1-2 already had an freeze-exception, as it fixes an RC bug.
The latest upstream version 3.4.2 includes all the patches we had
applied to 3.4.1 and adds a few bug fixes on top. Instead of
cherry-picking more upstream patches, I decided to just upload 3.4.2.

Included is the full debdiff between 3.4.1-2 and 3.4.2-1.
I've also attached a diffstat of 3.4.1 with all patches applied
against 3.4.2.

Cheers,
Michael

unblock gnome-bluetooth/3.4.2-1

-- System Information:
Debian Release: wheezy/sid
  APT prefers unstable
  APT policy: (500, 'unstable'), (200, 'experimental')
Architecture: amd64 (x86_64)
Foreign Architectures: i386

Kernel: Linux 3.2.0-3-amd64 (SMP w/4 CPU cores)
Locale: LANG=de_DE.utf8, LC_CTYPE=de_DE.utf8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash
 ChangeLog                                                      |  114 ++++
 NEWS                                                           |   12 
 applet/bluetooth-applet.c                                      |    8 
 configure                                                      |   20 
 configure.ac                                                   |    2 
 debian/changelog                                               |   12 
 debian/control                                                 |    2 
 debian/patches/02_Fix-return-of-RequestConfirmation-call.patch |   30 -
 debian/patches/03_Fix_wizard_blocked_in_finish_page.patch      |   34 -
 debian/patches/04_fix_incoming_pairing.patch                   |   45 -
 debian/patches/05_fix_memory_leak.patch                        |   41 -
 debian/patches/series                                          |    4 
 docs/reference/libgnome-bluetooth/html/ch01.html               |    2 
 docs/reference/libgnome-bluetooth/html/index.html              |    2 
 docs/reference/libgnome-bluetooth/version.xml                  |    2 
 lib/bluetooth-agent.c                                          |    7 
 lib/bluetooth-client-glue.c                                    |   80 +--
 lib/bluetooth-client-glue.h                                    |   18 
 lib/bluetooth-client.c                                         |   22 
 lib/bluetooth-client.xml                                       |    4 
 po/as.po                                                       |  181 ++++---
 po/el.po                                                       |  240 +++++-----
 wizard/main.c                                                  |    2 
 23 files changed, 455 insertions(+), 429 deletions(-)
diff -Nru gnome-bluetooth-3.4.1/applet/bluetooth-applet.c gnome-bluetooth-3.4.2/applet/bluetooth-applet.c
--- gnome-bluetooth-3.4.1/applet/bluetooth-applet.c	2012-06-12 17:25:28.000000000 +0200
+++ gnome-bluetooth-3.4.2/applet/bluetooth-applet.c	2012-07-02 12:21:54.000000000 +0200
@@ -313,6 +313,7 @@
 {
 	GVariant *value;
 	GVariant *result;
+	GVariant *dict;
 	char *alias, *address;
 
 	g_return_val_if_fail (long_name != NULL, NULL);
@@ -322,14 +323,17 @@
 	if (result == NULL)
 		return NULL;
 
-	value = g_variant_lookup_value (result, "Address", G_VARIANT_TYPE_STRING);
+	/* Retrieve the dictionary */
+	dict  = g_variant_get_child_value (result, 0);
+
+	value = g_variant_lookup_value (dict, "Address", G_VARIANT_TYPE_STRING);
 	if (value == NULL) {
 		g_variant_unref (result);
 		return NULL;
 	}
 	address = g_strdup (g_variant_get_string (value, NULL));
 
-	value = g_variant_lookup_value (result, "Name", G_VARIANT_TYPE_STRING);
+	value = g_variant_lookup_value (dict, "Name", G_VARIANT_TYPE_STRING);
 	alias = value ? g_strdup (g_variant_get_string (value, NULL)) : g_strdup (address);
 
 	g_variant_unref (result);
diff -Nru gnome-bluetooth-3.4.1/ChangeLog gnome-bluetooth-3.4.2/ChangeLog
--- gnome-bluetooth-3.4.1/ChangeLog	2012-06-12 19:12:36.000000000 +0200
+++ gnome-bluetooth-3.4.2/ChangeLog	2012-07-04 11:58:10.000000000 +0200
@@ -1,3 +1,117 @@
+commit 886a8a679a709b37562c1d326ff327fca9a5d7f3
+Author: Bastien Nocera <hadess@hadess.net>
+Date:   Wed Jul 4 10:57:52 2012 +0100
+
+    3.4.2
+
+ NEWS         |   12 ++++++++++++
+ configure.ac |    2 +-
+ 2 files changed, 13 insertions(+), 1 deletion(-)
+
+commit 6fbda2b161a3e0ee428d87c73e1fa6656f635d92
+Author: Sjoerd Simons <sjoerd@luon.net>
+Date:   Sun Jul 1 12:28:20 2012 +0200
+
+    applet: Fix device_get_name() in the applet
+    
+    g_dbus_proxy_call_sync returns a tuple with the results, not the results
+    directly. As such we first need to get the dictionary out of the tuple
+    before we can lookup the information in it.
+    
+    https://bugzilla.gnome.org/show_bug.cgi?id=674414
+
+ applet/bluetooth-applet.c |    8 ++++++--
+ 1 file changed, 6 insertions(+), 2 deletions(-)
+
+commit 749a81425d86f8fb0b02efa30b82a3fa79e67374
+Author: Sjoerd Simons <sjoerd@luon.net>
+Date:   Sat Jun 30 14:27:47 2012 +0200
+
+    lib: Fix stuck "Finishing page" for some devices
+    
+    Currently bluetooth_client_connect_service completes it async operation
+    directly when bailing (e.g. we don't have connectable service on the
+    remote device). This causes the bluetooth wizard to get stuck in the
+    Finishing page as it happens to go to this page *after* calling
+    bluetooth_client_connect_service.
+    
+    Making the async operation complete asynchronously fixes the
+    "stuck" page.
+    
+    https://bugzilla.gnome.org/show_bug.cgi?id=679190
+
+ lib/bluetooth-client.c |    2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+commit 48364bb1cb37b13ee26d6a86980287f4d3a1f7a6
+Author: Sjoerd Simons <sjoerd@luon.net>
+Date:   Sat Jun 30 10:45:45 2012 +0200
+
+    wizard: Fix Simple Pairing never succeeding
+    
+    The bluez RequestConfirmation call expect either an empty message (on
+    success) or an error (on failure) as return. The code tries to return
+    a string on success though, contrary to what the internal
+    introspection data says causing gdbus to just throw a warning
+    and bluez never getting a response, causing pairing to fail.
+    
+    Fix RequestConfirmation return value
+    
+    https://bugzilla.gnome.org/show_bug.cgi?id=679190
+
+ wizard/main.c |    2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+commit e66c4fe9f915d5952a2b16eabbc4ac2bafce7455
+Author: Sjoerd Simons <sjoerd@luon.net>
+Date:   Sun Jul 1 12:28:37 2012 +0200
+
+    Fix memory leak when registering the agent
+    
+    https://bugzilla.gnome.org/show_bug.cgi?id=679240
+
+ lib/bluetooth-agent.c |    7 +++++--
+ 1 file changed, 5 insertions(+), 2 deletions(-)
+
+commit f6bd77565e373e174f1dd800267c72ae1bc0f8b5
+Author: Nilamdyuti Goswami <nilamdyuti@gmail.com>
+Date:   Tue Jun 19 21:01:57 2012 +0530
+
+    Assamese translation reviewed
+
+ po/as.po |  181 +++++++++++++++++++++++++++++++++-----------------------------
+ 1 file changed, 96 insertions(+), 85 deletions(-)
+
+commit ee3dd9a60192aaf5a694f1b83fade4df8c00fba0
+Author: Bastien Nocera <hadess@hadess.net>
+Date:   Sat Jun 16 23:28:05 2012 +0200
+
+    lib: Fix use of wrong unref() call
+
+ lib/bluetooth-client.c |    2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+commit 84834da7411e675b3571066a6966d5ed462060a9
+Author: Bastien Nocera <hadess@hadess.net>
+Date:   Sat Jun 16 23:17:56 2012 +0200
+
+    lib: Don't use deprecated ListAdapters()
+    
+    https://bugzilla.gnome.org/show_bug.cgi?id=678228
+
+ lib/bluetooth-client.c   |   20 ++++++++++++++------
+ lib/bluetooth-client.xml |    4 ++--
+ 2 files changed, 16 insertions(+), 8 deletions(-)
+
+commit 153edba409efdf92aeb4bed5f6c93313f1d6ddc6
+Author: Tom Tryfonidis <tomtryf@gmail.com>
+Date:   Fri Jun 15 13:17:38 2012 +0300
+
+    Updated Greek translation
+
+ po/el.po |  240 +++++++++++++++++++++++++++++++++-----------------------------
+ 1 file changed, 128 insertions(+), 112 deletions(-)
+
 commit 386188f88d734e767d461303c915169657b4381a
 Author: Bastien Nocera <hadess@hadess.net>
 Date:   Tue Jun 12 18:12:08 2012 +0100
diff -Nru gnome-bluetooth-3.4.1/configure gnome-bluetooth-3.4.2/configure
--- gnome-bluetooth-3.4.1/configure	2012-06-12 19:12:23.000000000 +0200
+++ gnome-bluetooth-3.4.2/configure	2012-07-04 11:58:00.000000000 +0200
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.68 for gnome-bluetooth 3.4.1.
+# Generated by GNU Autoconf 2.68 for gnome-bluetooth 3.4.2.
 #
 # Report bugs to <http://bugzilla.gnome.org/enter_bug.cgi?product=gnome-bluetooth>.
 #
@@ -571,8 +571,8 @@
 # Identity of this package.
 PACKAGE_NAME='gnome-bluetooth'
 PACKAGE_TARNAME='gnome-bluetooth'
-PACKAGE_VERSION='3.4.1'
-PACKAGE_STRING='gnome-bluetooth 3.4.1'
+PACKAGE_VERSION='3.4.2'
+PACKAGE_STRING='gnome-bluetooth 3.4.2'
 PACKAGE_BUGREPORT='http://bugzilla.gnome.org/enter_bug.cgi?product=gnome-bluetooth'
 PACKAGE_URL=''
 
@@ -1466,7 +1466,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures gnome-bluetooth 3.4.1 to adapt to many kinds of systems.
+\`configure' configures gnome-bluetooth 3.4.2 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1536,7 +1536,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of gnome-bluetooth 3.4.1:";;
+     short | recursive ) echo "Configuration of gnome-bluetooth 3.4.2:";;
    esac
   cat <<\_ACEOF
 
@@ -1710,7 +1710,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-gnome-bluetooth configure 3.4.1
+gnome-bluetooth configure 3.4.2
 generated by GNU Autoconf 2.68
 
 Copyright (C) 2010 Free Software Foundation, Inc.
@@ -1988,7 +1988,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by gnome-bluetooth $as_me 3.4.1, which was
+It was created by gnome-bluetooth $as_me 3.4.2, which was
 generated by GNU Autoconf 2.68.  Invocation command line was
 
   $ $0 $@
@@ -2809,7 +2809,7 @@
 
 # Define the identity of the package.
  PACKAGE='gnome-bluetooth'
- VERSION='3.4.1'
+ VERSION='3.4.2'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -16862,7 +16862,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by gnome-bluetooth $as_me 3.4.1, which was
+This file was extended by gnome-bluetooth $as_me 3.4.2, which was
 generated by GNU Autoconf 2.68.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -16928,7 +16928,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-gnome-bluetooth config.status 3.4.1
+gnome-bluetooth config.status 3.4.2
 configured by $0, generated by GNU Autoconf 2.68,
   with options \\"\$ac_cs_config\\"
 
diff -Nru gnome-bluetooth-3.4.1/configure.ac gnome-bluetooth-3.4.2/configure.ac
--- gnome-bluetooth-3.4.1/configure.ac	2012-06-12 17:25:28.000000000 +0200
+++ gnome-bluetooth-3.4.2/configure.ac	2012-07-04 11:57:49.000000000 +0200
@@ -2,7 +2,7 @@
 
 m4_define(gnomebt_version_major, 3)
 m4_define(gnomebt_version_minor, 4)
-m4_define(gnomebt_version_micro, 1)
+m4_define(gnomebt_version_micro, 2)
 
 AC_INIT([gnome-bluetooth],
         [gnomebt_version_major.gnomebt_version_minor.gnomebt_version_micro],
diff -Nru gnome-bluetooth-3.4.1/debian/changelog gnome-bluetooth-3.4.2/debian/changelog
--- gnome-bluetooth-3.4.1/debian/changelog	2012-07-02 09:15:51.000000000 +0200
+++ gnome-bluetooth-3.4.2/debian/changelog	2012-07-10 21:55:06.000000000 +0200
@@ -1,3 +1,15 @@
+gnome-bluetooth (3.4.2-1) unstable; urgency=low
+
+  [ Andreas Henriksson ]
+  * New upstream release.
+  * Drop Sjoerds patches, which has been merged upstream:
+    debian/patches/02_Fix-return-of-RequestConfirmation-call.patch
+    debian/patches/03_Fix_wizard_blocked_in_finish_page.patch
+    debian/patches/04_fix_incoming_pairing.patch
+    debian/patches/05_fix_memory_leak.patch
+
+ -- Michael Biebl <biebl@debian.org>  Tue, 10 Jul 2012 21:55:04 +0200
+
 gnome-bluetooth (3.4.1-2) unstable; urgency=low
 
   * Added: debian/patches/02_Fix-return-of-RequestConfirmation-call.patch,
diff -Nru gnome-bluetooth-3.4.1/debian/control gnome-bluetooth-3.4.2/debian/control
--- gnome-bluetooth-3.4.1/debian/control	2012-07-02 09:17:40.000000000 +0200
+++ gnome-bluetooth-3.4.2/debian/control	2012-07-10 22:05:36.000000000 +0200
@@ -7,7 +7,7 @@
 Section: gnome
 Priority: optional
 Maintainer: Debian GNOME Maintainers <pkg-gnome-maintainers@lists.alioth.debian.org>
-Uploaders: Emilio Pozuelo Monfort <pochu@debian.org>, Laurent Bigonville <bigon@debian.org>, Michael Biebl <biebl@debian.org>, Sjoerd Simons <sjoerd@debian.org>
+Uploaders: Laurent Bigonville <bigon@debian.org>, Michael Biebl <biebl@debian.org>, Sjoerd Simons <sjoerd@debian.org>
 Build-Depends: debhelper (>= 8.1.0~),
                cdbs (>= 0.4.93),
                gnome-pkg-tools,
diff -Nru gnome-bluetooth-3.4.1/debian/patches/02_Fix-return-of-RequestConfirmation-call.patch gnome-bluetooth-3.4.2/debian/patches/02_Fix-return-of-RequestConfirmation-call.patch
--- gnome-bluetooth-3.4.1/debian/patches/02_Fix-return-of-RequestConfirmation-call.patch	2012-06-30 10:47:58.000000000 +0200
+++ gnome-bluetooth-3.4.2/debian/patches/02_Fix-return-of-RequestConfirmation-call.patch	1970-01-01 01:00:00.000000000 +0100
@@ -1,30 +0,0 @@
-From 46212ad97de694db45af525cd200c52e6eafb93b Mon Sep 17 00:00:00 2001
-From: Sjoerd Simons <sjoerd@luon.net>
-Date: Sat, 30 Jun 2012 10:45:45 +0200
-Subject: [PATCH] Fix return of RequestConfirmation call
-
-The bluez RequestConfirmation call expect either an empty message (on
-success) or an error (on failure) as return. For some reason the code
-tries to return a string on success though, contrary to even what the
-internal introspection data says causing gdbus to just throw a warning
-and bluez never getting a response... Causing pairing to fail.
----
- wizard/main.c |    2 +-
- 1 file changed, 1 insertion(+), 1 deletion(-)
-
-diff --git a/wizard/main.c b/wizard/main.c
-index 417c84c..e7cc9cc 100644
---- a/wizard/main.c
-+++ b/wizard/main.c
-@@ -261,7 +261,7 @@ matches_cb (GtkButton *button,
- 	invocation = g_object_get_data (G_OBJECT (button), "invocation");
- 	gtk_widget_set_sensitive (does_not_match_button, FALSE);
- 	gtk_widget_set_sensitive (matches_button, FALSE);
--	g_dbus_method_invocation_return_value (invocation, g_variant_new ("(s)", ""));
-+	g_dbus_method_invocation_return_value (invocation, NULL);
- 
- 	g_object_set_data (G_OBJECT(does_not_match_button), "invocation", NULL);
- 	g_object_set_data (G_OBJECT(matches_button), "invocation", NULL);
--- 
-1.7.10
-
diff -Nru gnome-bluetooth-3.4.1/debian/patches/03_Fix_wizard_blocked_in_finish_page.patch gnome-bluetooth-3.4.2/debian/patches/03_Fix_wizard_blocked_in_finish_page.patch
--- gnome-bluetooth-3.4.1/debian/patches/03_Fix_wizard_blocked_in_finish_page.patch	2012-07-01 12:29:01.000000000 +0200
+++ gnome-bluetooth-3.4.2/debian/patches/03_Fix_wizard_blocked_in_finish_page.patch	1970-01-01 01:00:00.000000000 +0100
@@ -1,34 +0,0 @@
-From bb1e1a273e49b11b38106042fdf430a38343f8d1 Mon Sep 17 00:00:00 2001
-From: Sjoerd Simons <sjoerd@luon.net>
-Date: Sat, 30 Jun 2012 14:27:47 +0200
-Subject: [PATCH 2/4] When bailing from a connect attempt use
- _complete_in_idle
-
-Currently bluetooth_client_connect_service complets it async operation
-directly when bailing (e.g. we don't have connectable service on the
-remote device). This causes the bluetooth wizard to get stuck in the
-Finishing page as it happens to go to this page *after* calling
-bluetooth_client_connect_service.
-
-Simply make the async operation complete asynchronously (like it should)
-and everything is happy again :)
----
- lib/bluetooth-client.c |    2 +-
- 1 file changed, 1 insertion(+), 1 deletion(-)
-
-diff --git a/lib/bluetooth-client.c b/lib/bluetooth-client.c
-index 21bcd38..73e987d 100644
---- a/lib/bluetooth-client.c
-+++ b/lib/bluetooth-client.c
-@@ -1870,7 +1870,7 @@ bluetooth_client_connect_service (BluetoothClient     *client,
- 
- bail:
- 	g_simple_async_result_set_op_res_gboolean (simple, res);
--	g_simple_async_result_complete (simple);
-+	g_simple_async_result_complete_in_idle (simple);
- 	g_object_unref (simple);
- }
- 
--- 
-1.7.10
-
diff -Nru gnome-bluetooth-3.4.1/debian/patches/04_fix_incoming_pairing.patch gnome-bluetooth-3.4.2/debian/patches/04_fix_incoming_pairing.patch
--- gnome-bluetooth-3.4.1/debian/patches/04_fix_incoming_pairing.patch	2012-07-01 12:29:18.000000000 +0200
+++ gnome-bluetooth-3.4.2/debian/patches/04_fix_incoming_pairing.patch	1970-01-01 01:00:00.000000000 +0100
@@ -1,45 +0,0 @@
-From 4ea6a4ead9440d3b3b1e38623535c53adbf1be32 Mon Sep 17 00:00:00 2001
-From: Sjoerd Simons <sjoerd@luon.net>
-Date: Sun, 1 Jul 2012 12:28:20 +0200
-Subject: [PATCH 3/4] g_dbus_proxy_call_sync returns a tuple with the results,
- not the results directly
-
----
- applet/bluetooth-applet.c |    8 ++++++--
- 1 file changed, 6 insertions(+), 2 deletions(-)
-
-diff --git a/applet/bluetooth-applet.c b/applet/bluetooth-applet.c
-index 0eb2973..32d373e 100644
---- a/applet/bluetooth-applet.c
-+++ b/applet/bluetooth-applet.c
-@@ -313,6 +313,7 @@ device_get_name (GDBusProxy *proxy, char **long_name)
- {
- 	GVariant *value;
- 	GVariant *result;
-+	GVariant *dict;
- 	char *alias, *address;
- 
- 	g_return_val_if_fail (long_name != NULL, NULL);
-@@ -322,14 +323,17 @@ device_get_name (GDBusProxy *proxy, char **long_name)
- 	if (result == NULL)
- 		return NULL;
- 
--	value = g_variant_lookup_value (result, "Address", G_VARIANT_TYPE_STRING);
-+	/* Retrieve the dictionary */
-+	dict  = g_variant_get_child_value (result, 0);
-+
-+	value = g_variant_lookup_value (dict, "Address", G_VARIANT_TYPE_STRING);
- 	if (value == NULL) {
- 		g_variant_unref (result);
- 		return NULL;
- 	}
- 	address = g_strdup (g_variant_get_string (value, NULL));
- 
--	value = g_variant_lookup_value (result, "Name", G_VARIANT_TYPE_STRING);
-+	value = g_variant_lookup_value (dict, "Name", G_VARIANT_TYPE_STRING);
- 	alias = value ? g_strdup (g_variant_get_string (value, NULL)) : g_strdup (address);
- 
- 	g_variant_unref (result);
--- 
-1.7.10
-
diff -Nru gnome-bluetooth-3.4.1/debian/patches/05_fix_memory_leak.patch gnome-bluetooth-3.4.2/debian/patches/05_fix_memory_leak.patch
--- gnome-bluetooth-3.4.1/debian/patches/05_fix_memory_leak.patch	2012-07-01 12:29:46.000000000 +0200
+++ gnome-bluetooth-3.4.2/debian/patches/05_fix_memory_leak.patch	1970-01-01 01:00:00.000000000 +0100
@@ -1,41 +0,0 @@
-From 23bc16eab6253cb84f9ac5cee2029131cc2c8d04 Mon Sep 17 00:00:00 2001
-From: Sjoerd Simons <sjoerd@luon.net>
-Date: Sun, 1 Jul 2012 12:28:37 +0200
-Subject: [PATCH 4/4] Fix memory leak when registering the agent
-
----
- lib/bluetooth-agent.c |    6 ++++--
- 1 file changed, 4 insertions(+), 2 deletions(-)
-
-diff --git a/lib/bluetooth-agent.c b/lib/bluetooth-agent.c
-index 01273e1..2eece93 100644
---- a/lib/bluetooth-agent.c
-+++ b/lib/bluetooth-agent.c
-@@ -437,6 +437,7 @@ gboolean bluetooth_agent_register(BluetoothAgent *agent)
- 	BluetoothAgentPrivate *priv;
- 	GError *error = NULL;
- 	char *path;
-+	GVariant *r;
- 
- 	g_return_val_if_fail (BLUETOOTH_IS_AGENT (agent), FALSE);
- 
-@@ -469,13 +470,14 @@ gboolean bluetooth_agent_register(BluetoothAgent *agent)
- 		error = NULL;
- 	}
- 
--	if (g_dbus_proxy_call_sync (priv->adapter, "RegisterAgent",
-+	if ((r = g_dbus_proxy_call_sync (priv->adapter, "RegisterAgent",
- 				    g_variant_new ("(os)", priv->path, "DisplayYesNo"),
- 				    G_DBUS_CALL_FLAGS_NONE,
--				    -1, NULL, &error) == FALSE) {
-+				    -1, NULL, &error)) == NULL) {
- 		g_printerr ("Agent registration failed: %s\n", error->message);
- 		g_error_free (error);
- 	}
-+	g_variant_unref (r);
- 
- 	return TRUE;
- }
--- 
-1.7.10
-
diff -Nru gnome-bluetooth-3.4.1/debian/patches/series gnome-bluetooth-3.4.2/debian/patches/series
--- gnome-bluetooth-3.4.1/debian/patches/series	2012-07-01 12:58:57.000000000 +0200
+++ gnome-bluetooth-3.4.2/debian/patches/series	2012-07-05 19:44:32.000000000 +0200
@@ -1,5 +1 @@
 01_autostart_path.patch
-02_Fix-return-of-RequestConfirmation-call.patch
-03_Fix_wizard_blocked_in_finish_page.patch
-04_fix_incoming_pairing.patch
-05_fix_memory_leak.patch
diff -Nru gnome-bluetooth-3.4.1/docs/reference/libgnome-bluetooth/html/ch01.html gnome-bluetooth-3.4.2/docs/reference/libgnome-bluetooth/html/ch01.html
--- gnome-bluetooth-3.4.1/docs/reference/libgnome-bluetooth/html/ch01.html	2012-06-12 19:12:47.000000000 +0200
+++ gnome-bluetooth-3.4.2/docs/reference/libgnome-bluetooth/html/ch01.html	2012-07-04 11:58:17.000000000 +0200
@@ -21,7 +21,7 @@
 </tr></table>
 <div class="chapter">
 <div class="titlepage"><div><div><h2 class="title">
-<a name="id354493"></a>API Reference</h2></div></div></div>
+<a name="id489047"></a>API Reference</h2></div></div></div>
 <div class="toc"><dl>
 <dt>
 <span class="refentrytitle"><a href="BluetoothClient.html">BluetoothClient</a></span><span class="refpurpose"> — Bluetooth client object</span>
diff -Nru gnome-bluetooth-3.4.1/docs/reference/libgnome-bluetooth/html/index.html gnome-bluetooth-3.4.2/docs/reference/libgnome-bluetooth/html/index.html
--- gnome-bluetooth-3.4.1/docs/reference/libgnome-bluetooth/html/index.html	2012-06-12 19:12:47.000000000 +0200
+++ gnome-bluetooth-3.4.2/docs/reference/libgnome-bluetooth/html/index.html	2012-07-04 11:58:17.000000000 +0200
@@ -15,7 +15,7 @@
 <div>
 <div><table class="navigation" id="top" width="100%" cellpadding="2" cellspacing="0"><tr><th valign="middle"><p class="title">gnome-bluetooth Reference Manual</p></th></tr></table></div>
 <div><p class="releaseinfo">
-      for gnome-bluetooth 3.4.1
+      for gnome-bluetooth 3.4.2
 .
       The latest version of this documentation can be found on-line at
       <a class="ulink" href="http://library.gnome.org/devel/gnome-bluetooth/unstable/"; target="_top">http://library.gnome.org/devel/gnome-bluetooth/unstable/</a>.
diff -Nru gnome-bluetooth-3.4.1/docs/reference/libgnome-bluetooth/version.xml gnome-bluetooth-3.4.2/docs/reference/libgnome-bluetooth/version.xml
--- gnome-bluetooth-3.4.1/docs/reference/libgnome-bluetooth/version.xml	2012-06-12 19:12:32.000000000 +0200
+++ gnome-bluetooth-3.4.2/docs/reference/libgnome-bluetooth/version.xml	2012-07-04 11:58:07.000000000 +0200
@@ -1 +1 @@
-3.4.1
+3.4.2
diff -Nru gnome-bluetooth-3.4.1/lib/bluetooth-agent.c gnome-bluetooth-3.4.2/lib/bluetooth-agent.c
--- gnome-bluetooth-3.4.1/lib/bluetooth-agent.c	2012-06-12 17:25:28.000000000 +0200
+++ gnome-bluetooth-3.4.2/lib/bluetooth-agent.c	2012-07-02 12:10:26.000000000 +0200
@@ -437,6 +437,7 @@
 	BluetoothAgentPrivate *priv;
 	GError *error = NULL;
 	char *path;
+	GVariant *r;
 
 	g_return_val_if_fail (BLUETOOTH_IS_AGENT (agent), FALSE);
 
@@ -469,13 +470,15 @@
 		error = NULL;
 	}
 
-	if (g_dbus_proxy_call_sync (priv->adapter, "RegisterAgent",
+	r = g_dbus_proxy_call_sync (priv->adapter, "RegisterAgent",
 				    g_variant_new ("(os)", priv->path, "DisplayYesNo"),
 				    G_DBUS_CALL_FLAGS_NONE,
-				    -1, NULL, &error) == FALSE) {
+				    -1, NULL, &error);
+	if (r == NULL) {
 		g_printerr ("Agent registration failed: %s\n", error->message);
 		g_error_free (error);
 	}
+	g_variant_unref (r);
 
 	return TRUE;
 }
diff -Nru gnome-bluetooth-3.4.1/lib/bluetooth-client.c gnome-bluetooth-3.4.2/lib/bluetooth-client.c
--- gnome-bluetooth-3.4.1/lib/bluetooth-client.c	2012-06-12 17:25:28.000000000 +0200
+++ gnome-bluetooth-3.4.2/lib/bluetooth-client.c	2012-07-02 12:17:11.000000000 +0200
@@ -949,7 +949,8 @@
 		   BluetoothClient *client)
 {
 	BluetoothClientPrivate *priv = BLUETOOTH_CLIENT_GET_PRIVATE(client);
-	char **array = NULL;
+	GVariant *variant;
+	const char **array;
 	gchar *default_path = NULL;
 
 	priv->manager = manager_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
@@ -962,13 +963,21 @@
 	g_signal_connect (G_OBJECT (priv->manager), "g-signal",
 			  G_CALLBACK (manager_g_signal), client);
 
-	if (manager_call_list_adapters_sync (priv->manager, &array, NULL, NULL)) {
+	manager_call_get_properties_sync (MANAGER (priv->manager), &variant, NULL, NULL);
+	if (variant != NULL) {
+		GVariant *v;
 		guint i;
 
-		for (i = 0; array[i] != NULL; i++)
-			adapter_added(priv->manager, array[i], client);
+		v = g_variant_lookup_value (variant, "Adapters", G_VARIANT_TYPE_OBJECT_PATH_ARRAY);
+		array = v ? g_variant_get_objv (v, NULL) : NULL;
+
+		if (array != NULL) {
+			for (i = 0; array[i] != NULL; i++)
+				adapter_added(priv->manager, array[i], client);
+			g_free (array);
+		}
 
-		g_strfreev (array);
+		g_variant_unref (variant);
 	}
 
 	manager_call_default_adapter_sync (priv->manager, &default_path, NULL, NULL);
@@ -976,7 +985,6 @@
 		default_adapter_changed (priv->manager, default_path, client);
 		g_free(default_path);
 	}
-
 }
 
 static void
@@ -1862,7 +1870,7 @@
 
 bail:
 	g_simple_async_result_set_op_res_gboolean (simple, res);
-	g_simple_async_result_complete (simple);
+	g_simple_async_result_complete_in_idle (simple);
 	g_object_unref (simple);
 }
 
diff -Nru gnome-bluetooth-3.4.1/lib/bluetooth-client-glue.h gnome-bluetooth-3.4.2/lib/bluetooth-client-glue.h
--- gnome-bluetooth-3.4.1/lib/bluetooth-client-glue.h	2012-06-12 19:12:39.000000000 +0200
+++ gnome-bluetooth-3.4.2/lib/bluetooth-client-glue.h	2012-07-02 12:08:30.000000000 +0200
@@ -1,5 +1,5 @@
 /*
- * Generated by gdbus-codegen 2.33.1. DO NOT EDIT.
+ * Generated by gdbus-codegen 2.33.2. DO NOT EDIT.
  *
  * The license of this code is the same as for the source it was derived from.
  */
@@ -33,7 +33,7 @@
     Manager *object,
     GDBusMethodInvocation *invocation);
 
-  gboolean (*handle_list_adapters) (
+  gboolean (*handle_get_properties) (
     Manager *object,
     GDBusMethodInvocation *invocation);
 
@@ -63,10 +63,10 @@
     GDBusMethodInvocation *invocation,
     const gchar *unnamed_arg0);
 
-void manager_complete_list_adapters (
+void manager_complete_get_properties (
     Manager *object,
     GDBusMethodInvocation *invocation,
-    const gchar *const *unnamed_arg0);
+    GVariant *unnamed_arg0);
 
 
 
@@ -104,21 +104,21 @@
     GCancellable *cancellable,
     GError **error);
 
-void manager_call_list_adapters (
+void manager_call_get_properties (
     Manager *proxy,
     GCancellable *cancellable,
     GAsyncReadyCallback callback,
     gpointer user_data);
 
-gboolean manager_call_list_adapters_finish (
+gboolean manager_call_get_properties_finish (
     Manager *proxy,
-    gchar ***out_unnamed_arg0,
+    GVariant **out_unnamed_arg0,
     GAsyncResult *res,
     GError **error);
 
-gboolean manager_call_list_adapters_sync (
+gboolean manager_call_get_properties_sync (
     Manager *proxy,
-    gchar ***out_unnamed_arg0,
+    GVariant **out_unnamed_arg0,
     GCancellable *cancellable,
     GError **error);
 
diff -Nru gnome-bluetooth-3.4.1/lib/bluetooth-client.xml gnome-bluetooth-3.4.2/lib/bluetooth-client.xml
--- gnome-bluetooth-3.4.1/lib/bluetooth-client.xml	2012-06-12 17:25:28.000000000 +0200
+++ gnome-bluetooth-3.4.2/lib/bluetooth-client.xml	2012-06-27 23:40:06.000000000 +0200
@@ -6,8 +6,8 @@
       <arg type="o" direction="out"/>
     </method>
 
-    <method name="ListAdapters">
-      <arg type="ao" direction="out"/>
+    <method name="GetProperties">
+      <arg type="a{sv}" direction="out"/>
     </method>
 
     <signal name="AdapterAdded">
diff -Nru gnome-bluetooth-3.4.1/NEWS gnome-bluetooth-3.4.2/NEWS
--- gnome-bluetooth-3.4.1/NEWS	2012-06-12 19:11:53.000000000 +0200
+++ gnome-bluetooth-3.4.2/NEWS	2012-07-04 11:57:40.000000000 +0200
@@ -1,3 +1,15 @@
+ver 3.4.2:
+Library:
+- Support for BlueZ 5.0 API
+- Fix memory leak when registering the pairing agent
+
+Wizard:
+- Fix Simple Pairing never succeeding
+- Fix stuck "Finishing page" for some devices
+
+Applet:
+- Fix assertion in gnome-shell when a device requires authorisation
+
 ver 3.4.1:
 Library:
 - Fix potential crashes when registering pairing agents with no adapter present
diff -Nru gnome-bluetooth-3.4.1/po/as.po gnome-bluetooth-3.4.2/po/as.po
--- gnome-bluetooth-3.4.1/po/as.po	2012-06-12 17:25:28.000000000 +0200
+++ gnome-bluetooth-3.4.2/po/as.po	2012-06-27 23:40:06.000000000 +0200
@@ -9,8 +9,8 @@
 "Project-Id-Version: gnome-bluetooth master\n"
 "Report-Msgid-Bugs-To: http://bugzilla.gnome.org/enter_bug.";
 "cgi?product=gnome-bluetooth&keywords=I18N+L10N&component=general\n"
-"POT-Creation-Date: 2012-02-18 12:55+0000\n"
-"PO-Revision-Date: 2012-03-08 21:37+0530\n"
+"POT-Creation-Date: 2012-05-10 16:08+0000\n"
+"PO-Revision-Date: 2012-06-19 19:43+0530\n"
 "Last-Translator: Nilamdyuti Goswami <ngoswami@redhat.com>\n"
 "Language-Team: as_IN <kde-i18n-doc@kde.org>\n"
 "MIME-Version: 1.0\n"
@@ -24,7 +24,7 @@
 msgstr "ডিভাইচ নিৰ্বাচন কৰাৰ বাবে ক্লিক কৰক..."
 
 #: ../lib/bluetooth-chooser.c:135 ../lib/bluetooth-filter-widget.c:82
-#: ../lib/bluetooth-utils.c:89
+#: ../lib/bluetooth-utils.c:90
 msgid "Unknown"
 msgstr "অজ্ঞাত"
 
@@ -54,7 +54,7 @@
 
 #: ../lib/bluetooth-filter-widget.c:74
 msgid "Paired"
-msgstr "জুটি"
+msgstr "যোৰ"
 
 #: ../lib/bluetooth-filter-widget.c:76
 msgid "Trusted"
@@ -62,11 +62,11 @@
 
 #: ../lib/bluetooth-filter-widget.c:78
 msgid "Not paired or trusted"
-msgstr "জুটি বন্ধা অথবা বিশ্বস্ত নয়"
+msgstr "যোৰ বন্ধা অথবা বিশ্বস্ত নহয়"
 
 #: ../lib/bluetooth-filter-widget.c:80
 msgid "Paired or trusted"
-msgstr "জুটি বন্ধা অথবা বিশ্বস্ত"
+msgstr "যোৰ বন্ধা অথবা বিশ্বস্ত"
 
 #. This is the title of the filter section of the Bluetooth device chooser.
 #. * It used to say Show Only Bluetooth Devices With...
@@ -77,7 +77,7 @@
 #. The device category filter
 #: ../lib/bluetooth-filter-widget.c:247
 msgid "Device _category:"
-msgstr "ডিভাইচৰ বিভাগ: (_c)"
+msgstr "ডিভাইচৰ বিভাগ (_c):"
 
 #: ../lib/bluetooth-filter-widget.c:258
 msgid "Select the device category to filter"
@@ -86,7 +86,7 @@
 #. The device type filter
 #: ../lib/bluetooth-filter-widget.c:272
 msgid "Device _type:"
-msgstr "ডিভাইচৰ ধৰণ: (_t)"
+msgstr "ডিভাইচৰ ধৰণ (_t):"
 
 #: ../lib/bluetooth-filter-widget.c:289
 msgid "Select the device type to filter"
@@ -94,76 +94,76 @@
 
 #: ../lib/bluetooth-filter-widget.c:295
 msgid "Input devices (mice, keyboards, etc.)"
-msgstr "ইনপুট ডিভাইচসমূহ (মাউছসমূহ, কিবৰ্ডসমূহ, আদি.)"
+msgstr "ইনপুট ডিভাইচসমূহ (মাউছসমূহ, কিবৰ্ডসমূহ, ইত্যাদি)"
 
 #: ../lib/bluetooth-filter-widget.c:299
 msgid "Headphones, headsets and other audio devices"
 msgstr "হেড-ফোন, হেড-ছেট আৰু অন্যান্য অডিঅ' ডিভাইচসমূহ"
 
-#: ../lib/bluetooth-utils.c:58
+#: ../lib/bluetooth-utils.c:59
 msgid "All types"
 msgstr "সকলো ধৰণৰ"
 
-#: ../lib/bluetooth-utils.c:60
+#: ../lib/bluetooth-utils.c:61
 msgid "Phone"
 msgstr "ফোন"
 
-#: ../lib/bluetooth-utils.c:62
+#: ../lib/bluetooth-utils.c:63
 msgid "Modem"
 msgstr "মোডেম"
 
-#: ../lib/bluetooth-utils.c:64
+#: ../lib/bluetooth-utils.c:65
 msgid "Computer"
 msgstr "কমপিউটাৰ"
 
-#: ../lib/bluetooth-utils.c:66
+#: ../lib/bluetooth-utils.c:67
 msgid "Network"
 msgstr "নেটৱাৰ্ক"
 
 #. translators: a hands-free headset, a combination of a single speaker with a microphone
-#: ../lib/bluetooth-utils.c:69
+#: ../lib/bluetooth-utils.c:70
 msgid "Headset"
 msgstr "হেড-ছেট"
 
-#: ../lib/bluetooth-utils.c:71
+#: ../lib/bluetooth-utils.c:72
 msgid "Headphones"
-msgstr "হেড-ফোন"
+msgstr "হেড-ফোনসমূহ"
 
-#: ../lib/bluetooth-utils.c:73
+#: ../lib/bluetooth-utils.c:74
 msgid "Audio device"
 msgstr "অডিঅ' ডিভাইচ"
 
-#: ../lib/bluetooth-utils.c:75
+#: ../lib/bluetooth-utils.c:76
 msgid "Keyboard"
 msgstr "কিবৰ্ড"
 
-#: ../lib/bluetooth-utils.c:77
+#: ../lib/bluetooth-utils.c:78
 msgid "Mouse"
 msgstr "মাউছ"
 
-#: ../lib/bluetooth-utils.c:79
+#: ../lib/bluetooth-utils.c:80
 msgid "Camera"
 msgstr "কেমেৰা"
 
-#: ../lib/bluetooth-utils.c:81
+#: ../lib/bluetooth-utils.c:82
 msgid "Printer"
 msgstr "প্ৰিন্টাৰ"
 
-#: ../lib/bluetooth-utils.c:83
+#: ../lib/bluetooth-utils.c:84
 msgid "Joypad"
 msgstr "জয়-পেড"
 
-#: ../lib/bluetooth-utils.c:85
+#: ../lib/bluetooth-utils.c:86
 msgid "Tablet"
 msgstr "টেবলেট"
 
-#: ../lib/bluetooth-utils.c:87
+#: ../lib/bluetooth-utils.c:88
 msgid "Video device"
 msgstr "ভিডিঅ' ডিভাইচ"
 
 #: ../lib/plugins/geoclue.c:178
 msgid "Use this GPS device for Geolocation services"
-msgstr "Geolocation (ভৌগলিক অৱস্থান) সেৱাৰ বাবে এই GPS ডিভাইচ প্ৰয়োগ কৰক"
+msgstr "ভূঅৱস্থান সেৱাৰ বাবে এই GPS ডিভাইচ প্ৰয়োগ কৰক"
 
 #. translators:
 #. * This is in a test plugin, please make sure you add the "(test)" part,
@@ -173,22 +173,20 @@
 msgstr "আপোনাৰ মোবাইল ফোন সহযোগে ইন্টাৰনেট ব্যৱহাৰ কৰক (পৰীক্ষামূলক)"
 
 #: ../applet/main.c:230
-#| msgid "Turn On Bluetooth"
 msgid "Turn on Bluetooth"
 msgstr "ব্লুটুথ অন কৰক"
 
 #: ../applet/main.c:231 ../applet/notify.c:159
 msgid "Bluetooth: Off"
-msgstr "ব্লুটুথ: বন্ধ কৰক"
+msgstr "ব্লুটুথ: বন্ধ"
 
 #: ../applet/main.c:234
-#| msgid "Turn Off Bluetooth"
 msgid "Turn off Bluetooth"
 msgstr "ব্লুটুথ বন্ধ কৰক"
 
 #: ../applet/main.c:235 ../applet/notify.c:159
 msgid "Bluetooth: On"
-msgstr "ব্লুটুথ: আৰম্ভ কৰক"
+msgstr "ব্লুটুথ: অন"
 
 #: ../applet/main.c:240
 msgid "Bluetooth: Disabled"
@@ -198,7 +196,7 @@
 msgid "Disconnecting..."
 msgstr "বিচ্ছিন্নিত কৰা হৈছে..."
 
-#: ../applet/main.c:390 ../sendto/main.c:206 ../sendto/main.c:308
+#: ../applet/main.c:390 ../sendto/main.c:192 ../sendto/main.c:292
 msgid "Connecting..."
 msgstr "সংযোত স্থাপন কৰা হৈছে..."
 
@@ -220,11 +218,11 @@
 
 #: ../applet/main.c:707
 msgid "Send files..."
-msgstr "নথিপত্ৰ পঠাওক..."
+msgstr "নথিপত্ৰসমূহ পঠাওক..."
 
 #: ../applet/main.c:717
 msgid "Browse files..."
-msgstr "নথিপত্ৰ ব্ৰাউছ কৰক..."
+msgstr "নথিপত্ৰসমূহ ব্ৰাউছ কৰক..."
 
 #: ../applet/main.c:728
 msgid "Keyboard Settings"
@@ -232,7 +230,7 @@
 
 #: ../applet/main.c:736
 msgid "Mouse and Touchpad Settings"
-msgstr "মাউচ আৰু টাচপেড সংহতিসমূহ"
+msgstr "মাউছ আৰু টাচপেড সংহতিসমূহ"
 
 #: ../applet/main.c:746
 msgid "Sound Settings"
@@ -268,7 +266,7 @@
 #: ../applet/agent.c:196 ../applet/agent.c:265
 #, c-format
 msgid "Device '%s' wants to pair with this computer"
-msgstr "'%s' ডিভাইচে এই কমপিউটাৰৰ সৈতে জুটি বান্ধীবলৈ ইচ্ছুক"
+msgstr "'%s' ডিভাইচে এই কমপিউটাৰৰ সৈতে যোৰ হবলৈ ইচ্ছুক"
 
 #: ../applet/agent.c:202
 #, c-format
@@ -286,19 +284,19 @@
 #: ../applet/agent.c:314
 #, c-format
 msgid "Grant access to '%s'"
-msgstr "'%s' ক অনুমোদন প্ৰদান কৰা হ'ব"
+msgstr "'%s' ক অভিগম প্ৰদান কৰক"
 
 #: ../applet/agent.c:319
 #, c-format
 msgid "Device %s wants access to the service '%s'."
-msgstr "%s ডিভাইচে  '%s'সেৱালে অভিগম বিচাৰে।"
+msgstr "%s ডিভাইচে  '%s' সেৱালে অভিগম বিচাৰে।"
 
 #. translators: this is a popup telling you a particular device
 #. * has asked for pairing
 #: ../applet/agent.c:369
 #, c-format
 msgid "Pairing request for '%s'"
-msgstr "'%s ৰ পৰা প্ৰাপ্ত জুটি বন্ধাৰ অনুৰোধ"
+msgstr "'%s ৰ পৰা প্ৰাপ্ত যোৰ বন্ধাৰ অনুৰোধ"
 
 #: ../applet/agent.c:371 ../applet/agent.c:404 ../applet/agent.c:434
 msgid "Bluetooth device"
@@ -306,14 +304,14 @@
 
 #: ../applet/agent.c:372
 msgid "Enter PIN"
-msgstr "PIN সোমাওক"
+msgstr "PIN সুমুৱাওক"
 
 #. translators: this is a popup telling you a particular device
 #. * has asked for pairing
 #: ../applet/agent.c:396
 #, c-format
 msgid "Pairing confirmation for '%s'"
-msgstr "'%s ৰ পৰা প্ৰাপ্ত জুটি নিৰ্মাণৰ নিশ্চিতি"
+msgstr "'%s ৰ পৰা প্ৰাপ্ত যোৰ নিৰ্মাণৰ নিশ্চিতি"
 
 #: ../applet/agent.c:405
 msgid "Verify PIN"
@@ -322,11 +320,11 @@
 #: ../applet/agent.c:432
 #, c-format
 msgid "Authorization request from '%s'"
-msgstr "'%s ৰ পৰা প্ৰাপ্ত অনুমোদনৰ অনুৰোধ"
+msgstr "'%s ৰ পৰা প্ৰাপ্ত প্ৰমাণীকৰণৰ অনুৰোধ"
 
 #: ../applet/agent.c:435
 msgid "Check authorization"
-msgstr "অনুমোদন পৰীক্ষা কৰক"
+msgstr "প্ৰমাণীকৰণ পৰীক্ষা কৰক"
 
 #: ../applet/bluetooth-applet.desktop.in.in.h:1
 msgid "Bluetooth Manager"
@@ -353,7 +351,6 @@
 msgstr "নতুন ডিভাইচ সংস্থাপন কৰক..."
 
 #: ../applet/popup-menu.ui.h:6
-#| msgid "Bluetooth: Checking"
 msgid "Bluetooth Settings"
 msgstr "ব্লুটুথ সংহতিসমূহ"
 
@@ -363,7 +360,7 @@
 
 #: ../applet/authorisation-dialogue.ui.h:1
 msgid "_Always grant access"
-msgstr "সৰ্বদা অনুমতি প্ৰদান কৰক (_A)"
+msgstr "সদায় অভিগম প্ৰদান কৰক (_A)"
 
 #: ../applet/authorisation-dialogue.ui.h:2
 msgid "_Reject"
@@ -392,12 +389,12 @@
 #: ../wizard/main.c:241 ../wizard/main.c:364
 #, c-format
 msgid "Pairing with '%s' cancelled"
-msgstr "'%s'-ৰ সৈতে নিৰ্ধাৰিত জুটি বাতিল কৰা হৈছে"
+msgstr "'%s' ৰ সৈতে নিৰ্ধাৰিত যোৰ বাতিল কৰা হৈছে"
 
 #: ../wizard/main.c:282
 #, c-format
 msgid "Please confirm that the PIN displayed on '%s' matches this one."
-msgstr "অনুগ্ৰহ কৰি নিশ্চিত কৰক, এই PIN আৰু '%s'-ত প্ৰদৰ্শিত PIN একেই হয় নে নহয়।"
+msgstr "অনুগ্ৰহ কৰি নিশ্চিত কৰক, এই PIN আৰু '%s' ত প্ৰদৰ্শিত PIN একেই হয় নে নহয়।"
 
 #: ../wizard/main.c:336
 msgid "Please enter the following PIN:"
@@ -419,17 +416,17 @@
 #: ../wizard/main.c:478
 #, c-format
 msgid "Connecting to '%s'..."
-msgstr "'%s'-ৰ সৈতে সংযোগ স্থাপন কৰা হৈছে..."
+msgstr "'%s' ৰ সৈতে সংযোগ স্থাপন কৰা হৈছে..."
 
 #: ../wizard/main.c:518
 #, c-format
 msgid "Please enter the following PIN on '%s':"
-msgstr "অনুগ্ৰহ কৰি '%s'-ত নিম্নলিখিত PIN লিখক:"
+msgstr "অনুগ্ৰহ কৰি '%s' ত নিম্নলিখিত PIN লিখক:"
 
 #: ../wizard/main.c:521
 #, c-format
 msgid "Please enter the following PIN on '%s' and press “Enter” on the keyboard:"
-msgstr "অনুগ্ৰহ কৰি '%s'-ত নিম্নলিখিত PIN লিখক আৰু কি-বোৰ্ডৰ পৰা “Enter” টিপক:"
+msgstr "অনুগ্ৰহ কৰি '%s' ত নিম্নলিখিত PIN লিখক আৰু কিবৰ্ডৰ পৰা “Enter” টিপক:"
 
 #: ../wizard/main.c:526
 msgid "Please move the joystick of your iCade in the following directions:"
@@ -455,10 +452,9 @@
 
 #: ../wizard/wizard.ui.h:2
 msgid "PIN _options..."
-msgstr "PIN বিকল্পসমূহ...(_o)"
+msgstr "PIN বিকল্পসমূহ (_o)..."
 
 #: ../wizard/wizard.ui.h:3
-#| msgid "Device search"
 msgid "Device Search"
 msgstr "ডিভাইচ সন্ধান"
 
@@ -505,7 +501,7 @@
 
 #: ../wizard/wizard.ui.h:15
 msgid "Do not pair"
-msgstr "মিল পোৱা নাযায়"
+msgstr "যোৰ নাবান্ধিব"
 
 #: ../wizard/wizard.ui.h:16
 msgid "Custom PIN:"
@@ -516,7 +512,6 @@
 msgstr "পুনৰ চেষ্টা কৰক (_T)"
 
 #: ../wizard/wizard.ui.h:18
-#| msgid "Quit"
 msgid "_Quit"
 msgstr "প্ৰস্থান কৰক (_Q)"
 
@@ -547,106 +542,119 @@
 msgid "%'d second"
 msgid_plural "%'d seconds"
 msgstr[0] "%'d ছেকেণ্ড"
-msgstr[1] "%'d ছেকেণ্ডসমূহ"
+msgstr[1] "%'d ছেকেণ্ড"
 
 #: ../sendto/main.c:156 ../sendto/main.c:169
 #, c-format
 msgid "%'d minute"
 msgid_plural "%'d minutes"
 msgstr[0] "%'d মিনিট"
-msgstr[1] "%'d মিনিটসমূহ"
+msgstr[1] "%'d মিনিট"
 
 #: ../sendto/main.c:167
 #, c-format
 msgid "%'d hour"
 msgid_plural "%'d hours"
 msgstr[0] "%'d ঘন্টা"
-msgstr[1] "%'d ঘন্টাসমূহ"
+msgstr[1] "%'d ঘন্টা"
 
 #: ../sendto/main.c:177
 #, c-format
 msgid "approximately %'d hour"
 msgid_plural "approximately %'d hours"
 msgstr[0] "আনুমানিক %'d ঘন্টা"
-msgstr[1] "আনুমানিক %'d ঘন্টাসমূহ"
+msgstr[1] "আনুমানিক %'d ঘন্টা"
 
-#: ../sendto/main.c:245
+#: ../sendto/main.c:231
 msgid "File Transfer"
 msgstr "নথিপত্ৰ স্থানান্তৰ"
 
-#: ../sendto/main.c:249
+#: ../sendto/main.c:234
 msgid "_Retry"
 msgstr "পুনৰ চেষ্টা কৰক (_R)"
 
 #. translators: This is the heading for the progress dialogue
-#: ../sendto/main.c:269
+#: ../sendto/main.c:253
 msgid "Sending files via Bluetooth"
 msgstr "ব্লুটুথৰ মাধ্যমে নথিপত্ৰ পঠিওৱা হৈছে"
 
-#: ../sendto/main.c:281
+#: ../sendto/main.c:265
 msgid "From:"
 msgstr "উৎসস্থল:"
 
-#: ../sendto/main.c:293
+#: ../sendto/main.c:277
 msgid "To:"
 msgstr "গন্তব্যস্থল:"
 
-#: ../sendto/main.c:337 ../sendto/main.c:355
+#: ../sendto/main.c:321 ../sendto/main.c:339
 msgid "An unknown error occurred"
 msgstr "অজ্ঞাত ত্ৰুটি দেখা দিছে"
 
-#: ../sendto/main.c:348
+#: ../sendto/main.c:332
 msgid ""
 "Make sure that the remote device is switched on and that it accepts "
 "Bluetooth connections"
 msgstr ""
 "দূৰবৰ্তী ডিভাইচটো সামৰ্থবান হয় নে নহয় আৰু ডিভাইচটো দ্বাৰা ব্লুটুথ সংযোগ গ্ৰহণ কৰা "
-"হৈছে নে নহয় সেইটো পৰীক্ষা কৰক"
+"হৈছে নে নাই সেইটো পৰীক্ষা কৰক"
 
-#: ../sendto/main.c:446
+#: ../sendto/main.c:430
 #, c-format
 msgid "Sending %s"
 msgstr "%s পঠিওৱা হৈছে"
 
-#: ../sendto/main.c:453 ../sendto/main.c:524
+#: ../sendto/main.c:437 ../sendto/main.c:508
 #, c-format
 msgid "Sending file %d of %d"
-msgstr "%d নথিপত্ৰ পঠিওৱা হৈছে, সৰ্বমোট %d"
+msgstr "%d ৰ %d পঠিওৱা হৈছে"
 
-#: ../sendto/main.c:520
+#: ../sendto/main.c:504
 #, c-format
-msgid "%d KB/s"
-msgstr "%d কিলোবাইট/ছেকেণ্ড"
+#| msgid "%d B/s"
+msgid "%d kB/s"
+msgstr "%d kB/s"
 
-#: ../sendto/main.c:522
+#: ../sendto/main.c:506
 #, c-format
 msgid "%d B/s"
-msgstr "%d বাইট/ছেকেণ্ড"
+msgstr "%d B/s"
 
-#: ../sendto/main.c:658
+#: ../sendto/main.c:639
 msgid "Select device to send to"
 msgstr "পঠিৱাব লগিয়া ডিভাইচ বাছক"
 
-#: ../sendto/main.c:663
+#: ../sendto/main.c:644
 msgid "_Send"
 msgstr "পঠাওক (_S)"
 
-#: ../sendto/main.c:707
+#: ../sendto/main.c:688
 msgid "Choose files to send"
 msgstr "পঠিওৱাৰ উদ্দেশ্যে নথিপত্ৰ নিৰ্বাচন কৰক"
 
-#: ../sendto/main.c:710
+#: ../sendto/main.c:691
 msgid "Select"
 msgstr "বাছক"
 
-#: ../sendto/main.c:736
+#: ../sendto/main.c:717
 msgid "Remote device to use"
 msgstr "ব্যৱহাৰযোগ্য দূৰবৰ্তী ডিভাইচ"
 
-#: ../sendto/main.c:738
+#: ../sendto/main.c:717
+msgid "ADDRESS"
+msgstr "ADDRESS"
+
+#: ../sendto/main.c:719
 msgid "Remote device's name"
 msgstr "দূৰবৰ্তী ডিভাইচৰ নাম"
 
+#: ../sendto/main.c:719
+msgid "NAME"
+msgstr "NAME"
+
+#: ../sendto/main.c:738
+msgid "[FILE...]"
+msgstr "[FILE...]"
+
 #: ../sendto/nautilus-sendto-plugin.c:168
 msgid "Programming error: could not find the device in the list"
 msgstr "প্ৰগ্ৰামিং ত্ৰুটি: ডিভাইচটো তালিকাত পোৱা নগল"
@@ -668,6 +676,9 @@
 msgid "Send files via Bluetooth"
 msgstr "ব্লুটুথৰ মাধ্যমে নথিপত্ৰ পঠিৱাওক"
 
+#~ msgid "%d KB/s"
+#~ msgstr "%d কিলোবাইট/ছেকেণ্ড"
+
 #~ msgid "Remove '%s' from the list of devices?"
 #~ msgstr "ডিভাইচৰ তালিকাৰ পৰা '%s' আঁতৰুৱা হ'ব নেকি ?"
 
@@ -714,7 +725,7 @@
 #~ msgstr "দৃশ্যমানতা"
 
 #~ msgid "Visibility of “%s”"
-#~ msgstr "“%s” -ৰ দৃশ্যমানতা"
+#~ msgstr "“%s” ৰ দৃশ্যমানতা"
 
 #~ msgid "Address"
 #~ msgstr "ঠিকনা"
@@ -811,14 +822,14 @@
 #~ "Your computer is visible on\n"
 #~ "Bluetooth for %s."
 #~ msgstr ""
-#~ "আপোনাৰ কমপিউটাৰৰ %s -ৰ\n"
+#~ "আপোনাৰ কমপিউটাৰৰ %s ৰ\n"
 #~ " বাবে ব্লুটুথত দৃশ্যমান।"
 
 #~ msgid "Pairing with %s failed."
-#~ msgstr "%s-ৰ সৈতে নিৰ্ধাৰিত জুটি পাতিবলে ব্যৰ্থ।"
+#~ msgstr "%sৰ সৈতে নিৰ্ধাৰিত যোৰ পাতিবলে ব্যৰ্থ।"
 
 #~ msgid "Pair"
-#~ msgstr "জুটি"
+#~ msgstr "যোৰ"
 
 #~ msgid "Browse"
 #~ msgstr "ব্ৰাউছ কৰক (_B)"
@@ -882,7 +893,7 @@
 #~ msgstr "অমিতাক্ষ ফুকন (aphukan@fedoraproject.org)"
 
 #~ msgid "GNOME Bluetooth home page"
-#~ msgstr "GNOME Bluetooth-ৰ প্ৰধান পৃষ্ঠা"
+#~ msgstr "GNOME Bluetoothৰ প্ৰধান পৃষ্ঠা"
 
 #~ msgid "Bluetooth Preferences"
 #~ msgstr "Bluetooth সংক্ৰান্ত পছন্দ"
@@ -894,7 +905,7 @@
 #~ msgstr "বৰ্তমানে জ্ঞাত ডিভাইচসমূহৰ তালিকা প্ৰদৰ্শন কৰা হ'ব"
 
 #~ msgid "Bluetooth Properties"
-#~ msgstr "Bluetooth-ৰ বিবিধ বৈশিষ্ট্য"
+#~ msgstr "Bluetoothৰ বিবিধ বৈশিষ্ট্য"
 
 #~| msgid "_Discoverable"
 #~ msgid "Make computer _discoverable"
diff -Nru gnome-bluetooth-3.4.1/po/el.po gnome-bluetooth-3.4.2/po/el.po
--- gnome-bluetooth-3.4.1/po/el.po	2012-06-12 17:25:28.000000000 +0200
+++ gnome-bluetooth-3.4.2/po/el.po	2012-07-04 11:52:40.000000000 +0200
@@ -10,15 +10,16 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: bluez-gnome\n"
-"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2012-05-02 13:16+0300\n"
-"PO-Revision-Date: 2012-04-23 12:01+0200\n"
+"Report-Msgid-Bugs-To: http://bugzilla.gnome.org/enter_bug.cgi?product=gnome-";
+"bluetooth&keywords=I18N+L10N&component=general\n"
+"POT-Creation-Date: 2012-06-12 17:14+0000\n"
+"PO-Revision-Date: 2012-06-15 12:57+0200\n"
 "Last-Translator: Tom Tryfonidis <tomtryf@gmail.com>\n"
 "Language-Team: Greek <team@gnome.gr>\n"
-"Language: el\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
+"Language: el\n"
 "Plural-Forms: nplurals=2; plural=(n != 1)\n"
 "X-Launchpad-Export-Date: 2008-10-05 13:37+0000\n"
 "X-Generator: Lokalize 0.3\n"
@@ -30,7 +31,7 @@
 msgstr "Κάνε κλικ για να επιλέξετε συσκευή…"
 
 #: ../lib/bluetooth-chooser.c:135 ../lib/bluetooth-filter-widget.c:82
-#: ../lib/bluetooth-utils.c:89
+#: ../lib/bluetooth-utils.c:90
 msgid "Unknown"
 msgstr "Άγνωστο"
 
@@ -38,19 +39,19 @@
 msgid "No adapters available"
 msgstr "Δεν υπάρχουν διαθέσιμοι προσαρμογείς"
 
-#: ../lib/bluetooth-chooser.c:180 ../lib/bluetooth-chooser.c:802
+#: ../lib/bluetooth-chooser.c:180 ../lib/bluetooth-chooser.c:804
 msgid "Searching for devices..."
 msgstr "Αναζήτηση για συσκευές…"
 
-#: ../lib/bluetooth-chooser.c:694 ../lib/bluetooth-chooser.c:983
+#: ../lib/bluetooth-chooser.c:696 ../lib/bluetooth-chooser.c:985
 msgid "Device"
 msgstr "Συσκευή"
 
-#: ../lib/bluetooth-chooser.c:730
+#: ../lib/bluetooth-chooser.c:732
 msgid "Type"
 msgstr "Τύπος"
 
-#: ../lib/bluetooth-chooser.c:985 ../applet/popup-menu.ui.h:3
+#: ../lib/bluetooth-chooser.c:987 ../applet/popup-menu.ui.h:4
 msgid "Devices"
 msgstr "Συσκευές"
 
@@ -106,64 +107,64 @@
 msgid "Headphones, headsets and other audio devices"
 msgstr "Ακουστικά και άλλες συσκευές ήχου"
 
-#: ../lib/bluetooth-utils.c:58
+#: ../lib/bluetooth-utils.c:59
 msgid "All types"
 msgstr "Όλοι οι τύποι"
 
-#: ../lib/bluetooth-utils.c:60
+#: ../lib/bluetooth-utils.c:61
 msgid "Phone"
 msgstr "Τηλέφωνο"
 
-#: ../lib/bluetooth-utils.c:62
+#: ../lib/bluetooth-utils.c:63
 msgid "Modem"
 msgstr "Μόντεμ"
 
-#: ../lib/bluetooth-utils.c:64
+#: ../lib/bluetooth-utils.c:65
 msgid "Computer"
 msgstr "Υπολογιστής"
 
-#: ../lib/bluetooth-utils.c:66
+#: ../lib/bluetooth-utils.c:67
 msgid "Network"
 msgstr "Δίκτυο"
 
 #. translators: a hands-free headset, a combination of a single speaker with a microphone
-#: ../lib/bluetooth-utils.c:69
+#: ../lib/bluetooth-utils.c:70
 msgid "Headset"
 msgstr "Ακουστικά"
 
-#: ../lib/bluetooth-utils.c:71
+#: ../lib/bluetooth-utils.c:72
 msgid "Headphones"
 msgstr "Ακουστικά"
 
-#: ../lib/bluetooth-utils.c:73
+#: ../lib/bluetooth-utils.c:74
 msgid "Audio device"
 msgstr "Συσκευή ήχου"
 
-#: ../lib/bluetooth-utils.c:75
+#: ../lib/bluetooth-utils.c:76
 msgid "Keyboard"
 msgstr "Πληκτρολόγιο"
 
-#: ../lib/bluetooth-utils.c:77
+#: ../lib/bluetooth-utils.c:78
 msgid "Mouse"
 msgstr "Ποντίκι"
 
-#: ../lib/bluetooth-utils.c:79
+#: ../lib/bluetooth-utils.c:80
 msgid "Camera"
 msgstr "Κάμερα"
 
-#: ../lib/bluetooth-utils.c:81
+#: ../lib/bluetooth-utils.c:82
 msgid "Printer"
 msgstr "Εκτυπωτής"
 
-#: ../lib/bluetooth-utils.c:83
+#: ../lib/bluetooth-utils.c:84
 msgid "Joypad"
 msgstr "Χειριστήριο παιχνιδιών"
 
-#: ../lib/bluetooth-utils.c:85
+#: ../lib/bluetooth-utils.c:86
 msgid "Tablet"
 msgstr "Πινακίδα αφής"
 
-#: ../lib/bluetooth-utils.c:87
+#: ../lib/bluetooth-utils.c:88
 msgid "Video device"
 msgstr "Συσκευή βίντεο"
 
@@ -202,7 +203,7 @@
 msgid "Disconnecting..."
 msgstr "Γίνεται αποσύνδεση…"
 
-#: ../applet/main.c:390 ../sendto/main.c:206 ../sendto/main.c:308
+#: ../applet/main.c:390 ../sendto/main.c:192 ../sendto/main.c:292
 msgid "Connecting..."
 msgstr "Γίνεται σύνδεση…"
 
@@ -283,8 +284,8 @@
 #, c-format
 msgid "Please confirm whether the PIN '%s' matches the one on device %s."
 msgstr ""
-"Παρακαλώ επιβαιβεώστε ότι το PIN «%s» ταιριάζει με αυτό που είναι στη "
-"συσκευή %s."
+"Παρακαλώ επιβαιβεώστε ότι το PIN «%s» ταιριάζει με αυτό που είναι στη συσκευή "
+"%s."
 
 #. translators: Whether to grant access to a particular service
 #: ../applet/agent.c:314
@@ -341,41 +342,41 @@
 msgstr "Μικροεφαρμογή διαχείρισης Bluetooth"
 
 #: ../applet/popup-menu.ui.h:1
-msgid "Bluetooth Settings"
-msgstr "Ρυθμίσεις Bluetooth"
-
-#: ../applet/popup-menu.ui.h:2
 msgid "Bluetooth: Checking"
 msgstr "Bluetooth: Γίνεται έλεγχος"
 
-#: ../applet/popup-menu.ui.h:4
-msgid "Quit"
-msgstr "Έξοδος"
+#: ../applet/popup-menu.ui.h:2
+msgid "Visible"
+msgstr "Ορατό"
 
-#: ../applet/popup-menu.ui.h:5
+#: ../applet/popup-menu.ui.h:3
 msgid "Send files to device..."
 msgstr "Αποστολή αρχείων στη συσκευή…"
 
-#: ../applet/popup-menu.ui.h:6
+#: ../applet/popup-menu.ui.h:5
 msgid "Set up new device..."
 msgstr "Εγκατάσταση νέας συσκευής…"
 
+#: ../applet/popup-menu.ui.h:6
+msgid "Bluetooth Settings"
+msgstr "Ρυθμίσεις Bluetooth"
+
 #: ../applet/popup-menu.ui.h:7
-msgid "Visible"
-msgstr "Ορατό"
+msgid "Quit"
+msgstr "Έξοδος"
 
 #: ../applet/authorisation-dialogue.ui.h:1
 msgid "_Always grant access"
 msgstr "_Πάντα χορήγηση πρόσβασης"
 
 #: ../applet/authorisation-dialogue.ui.h:2
-msgid "_Grant"
-msgstr "_Χορήγηση"
-
-#: ../applet/authorisation-dialogue.ui.h:3
 msgid "_Reject"
 msgstr "_Απόρριψη"
 
+#: ../applet/authorisation-dialogue.ui.h:3
+msgid "_Grant"
+msgstr "_Χορήγηση"
+
 #: ../applet/confirm-dialogue.ui.h:1
 msgid "_Does not match"
 msgstr "_Δεν ταιριάζει"
@@ -446,100 +447,100 @@
 #. * The '%s' is the device name, for example:
 #. * Please wait while finishing setup on 'Sony Bluetooth Headset'...
 #.
-#: ../wizard/main.c:556
+#: ../wizard/main.c:558
 #, c-format
 msgid "Please wait while finishing setup on device '%s'..."
 msgstr "Παρακαλώ περιμένετε μέχρι το πέρας της ρύθμισης στη συσκευή «%s»…"
 
-#: ../wizard/main.c:574
+#: ../wizard/main.c:576
 #, c-format
 msgid "Successfully set up new device '%s'"
 msgstr "Επιτυχημένη ρύθμιση στη συσκευή «%s»"
 
 #: ../wizard/wizard.ui.h:1
-msgid "'0000' (most headsets, mice and GPS devices)"
-msgstr "«0000» (τα περισσότερα ακουστικά, ποντίκια και συσκευές GPS)"
+msgid "Bluetooth New Device Setup"
+msgstr "Ρύθμιση νέας συσκευής Bluetooth"
 
 #: ../wizard/wizard.ui.h:2
-msgid "'1111'"
-msgstr "«1111»"
+msgid "PIN _options..."
+msgstr "_Επιλογές PIN…"
 
 #: ../wizard/wizard.ui.h:3
-msgid "'1234'"
-msgstr "«1234»"
+msgid "Device Search"
+msgstr "Αναζήτηση συσκευής"
 
 #: ../wizard/wizard.ui.h:4
-msgid "Bluetooth New Device Setup"
-msgstr "Ρύθμιση νέας συσκευής Bluetooth"
+msgid "Device Setup"
+msgstr "Ρύθμιση συσκευής"
 
 #: ../wizard/wizard.ui.h:5
-msgid "Custom PIN:"
-msgstr "Προσαρμοσμένο PIN:"
+msgid "Finishing New Device Setup"
+msgstr "Ολοκλήρωση ρύθμισης νέας συσκευής"
 
 #: ../wizard/wizard.ui.h:6
-msgid "Device Search"
-msgstr "Αναζήτηση συσκευής"
+msgid "Select the additional services you want to use with your device:"
+msgstr ""
+"Επιλέξτε τις πρόσθετες υπηρεσίες που επιθυμείτε να χρησιμοποιήσετε με τη "
+"συσκευή σας:"
 
 #: ../wizard/wizard.ui.h:7
-msgid "Device Setup"
-msgstr "Ρύθμιση συσκευής"
+msgid "Setup Summary"
+msgstr "Περίληψη ρυθμίσεων"
 
 #: ../wizard/wizard.ui.h:8
-msgid "Do not pair"
-msgstr "Δε γίνεται σύζευξη"
-
-#. This is a button to answer: Does the PIN matches the one on the device?
-#: ../wizard/wizard.ui.h:10
-msgid "Does not match"
-msgstr "Δεν ταιριάζει"
+msgid "PIN Options"
+msgstr "Επιλογές PIN"
 
-#: ../wizard/wizard.ui.h:11
-msgid "Finishing New Device Setup"
-msgstr "Ολοκλήρωση ρύθμισης νέας συσκευής"
+#: ../wizard/wizard.ui.h:9
+msgid "_Automatic PIN selection"
+msgstr "_Αυτόματη επιλογή PIN"
 
 #. Translators: this is a PIN with a set value, such as 1111, or 0000
-#: ../wizard/wizard.ui.h:13
+#: ../wizard/wizard.ui.h:11
 msgid "Fixed PIN"
 msgstr "Σταθερό PIN"
 
-#. This is a button to answer: Does the PIN matches the one on the device?
+#: ../wizard/wizard.ui.h:12
+msgid "'0000' (most headsets, mice and GPS devices)"
+msgstr "«0000» (τα περισσότερα ακουστικά, ποντίκια και συσκευές GPS)"
+
+#: ../wizard/wizard.ui.h:13
+msgid "'1111'"
+msgstr "«1111»"
+
+#: ../wizard/wizard.ui.h:14
+msgid "'1234'"
+msgstr "«1234»"
+
 #: ../wizard/wizard.ui.h:15
-msgid "Matches"
-msgstr "Ταιριάζει"
+msgid "Do not pair"
+msgstr "Δε γίνεται σύζευξη"
 
 #: ../wizard/wizard.ui.h:16
-msgid "PIN Options"
-msgstr "Επιλογές PIN"
+msgid "Custom PIN:"
+msgstr "Προσαρμοσμένο PIN:"
 
 #: ../wizard/wizard.ui.h:17
-msgid "PIN _options..."
-msgstr "_Επιλογές PIN…"
+msgid "_Try Again"
+msgstr "_Επανάληψη προσπάθειας"
 
 #: ../wizard/wizard.ui.h:18
-msgid "Select the additional services you want to use with your device:"
-msgstr ""
-"Επιλέξτε τις πρόσθετες υπηρεσίες που επιθυμείτε να χρησιμοποιήσετε με τη "
-"συσκευή σας:"
+msgid "_Quit"
+msgstr "Έ_ξοδος"
 
 #: ../wizard/wizard.ui.h:19
-msgid "Setup Summary"
-msgstr "Περίληψη ρυθμίσεων"
-
-#: ../wizard/wizard.ui.h:20
-msgid "_Automatic PIN selection"
-msgstr "_Αυτόματη επιλογή PIN"
-
-#: ../wizard/wizard.ui.h:21
 msgid "_Cancel"
 msgstr "_Ακύρωση"
 
-#: ../wizard/wizard.ui.h:22
-msgid "_Quit"
-msgstr "Έ_ξοδος"
+#. This is a button to answer: Does the PIN matches the one on the device?
+#: ../wizard/wizard.ui.h:21
+msgid "Does not match"
+msgstr "Δεν ταιριάζει"
 
+#. This is a button to answer: Does the PIN matches the one on the device?
 #: ../wizard/wizard.ui.h:23
-msgid "_Try Again"
-msgstr "_Επανάληψη προσπάθειας"
+msgid "Matches"
+msgstr "Ταιριάζει"
 
 #: ../wizard/bluetooth-wizard.desktop.in.in.h:1
 msgid "Bluetooth Device Setup"
@@ -577,32 +578,32 @@
 msgstr[0] "περίπου %'d ώρα"
 msgstr[1] "περίπου %'d ώρες"
 
-#: ../sendto/main.c:245
+#: ../sendto/main.c:231
 msgid "File Transfer"
 msgstr "Μεταφορά αρχείων"
 
-#: ../sendto/main.c:249
+#: ../sendto/main.c:234
 msgid "_Retry"
 msgstr "Προσπάθεια _ξανά"
 
 #. translators: This is the heading for the progress dialogue
-#: ../sendto/main.c:269
+#: ../sendto/main.c:253
 msgid "Sending files via Bluetooth"
 msgstr "Αποστολή αρχείων μέσω Bluetooth"
 
-#: ../sendto/main.c:281
+#: ../sendto/main.c:265
 msgid "From:"
 msgstr "Από:"
 
-#: ../sendto/main.c:293
+#: ../sendto/main.c:277
 msgid "To:"
 msgstr "Προς:"
 
-#: ../sendto/main.c:337 ../sendto/main.c:355
+#: ../sendto/main.c:321 ../sendto/main.c:339
 msgid "An unknown error occurred"
 msgstr "Προέκυψε ένα άγνωστο σφάλμα"
 
-#: ../sendto/main.c:348
+#: ../sendto/main.c:332
 msgid ""
 "Make sure that the remote device is switched on and that it accepts "
 "Bluetooth connections"
@@ -610,50 +611,62 @@
 "Βεβαιωθείτε ότι η απομακρυσμένη συσκευή είναι ενεργοποιημένη και ότι δέχεται "
 "συνδέσεις Bluetooth"
 
-#: ../sendto/main.c:446
+#: ../sendto/main.c:430
 #, c-format
 msgid "Sending %s"
 msgstr "Αποστολή %s"
 
-#: ../sendto/main.c:453 ../sendto/main.c:524
+#: ../sendto/main.c:437 ../sendto/main.c:508
 #, c-format
 msgid "Sending file %d of %d"
 msgstr "Αποστολή αρχείου %d από %d"
 
-#: ../sendto/main.c:520
+#: ../sendto/main.c:504
 #, c-format
-msgid "%d KB/s"
-msgstr "%d KB/δευτ."
+msgid "%d kB/s"
+msgstr "%d kB/δευτ."
 
-#: ../sendto/main.c:522
+#: ../sendto/main.c:506
 #, c-format
 msgid "%d B/s"
 msgstr "%d B/δευτ."
 
-#: ../sendto/main.c:658
+#: ../sendto/main.c:639
 msgid "Select device to send to"
 msgstr "Επιλέξτε την συσκευή που θα γίνει αποστολή"
 
-#: ../sendto/main.c:663
+#: ../sendto/main.c:644
 msgid "_Send"
 msgstr "Α_ποστολή"
 
-#: ../sendto/main.c:707
+#: ../sendto/main.c:688
 msgid "Choose files to send"
 msgstr "Επιλογή αρχείων  για αποστολή"
 
-#: ../sendto/main.c:710
+#: ../sendto/main.c:691
 msgid "Select"
 msgstr "Επιλογή"
 
-#: ../sendto/main.c:736
+#: ../sendto/main.c:717
 msgid "Remote device to use"
 msgstr "Απομακρυσμένη συσκευή για χρήση"
 
-#: ../sendto/main.c:738
+#: ../sendto/main.c:717
+msgid "ADDRESS"
+msgstr "ΔΙΕΥΘΥΝΣΗ"
+
+#: ../sendto/main.c:719
 msgid "Remote device's name"
 msgstr "Το όνομα της απομακρυσμένης συσκευής"
 
+#: ../sendto/main.c:719
+msgid "NAME"
+msgstr "ΟΝΟΜΑ"
+
+#: ../sendto/main.c:738
+msgid "[FILE...]"
+msgstr "[ΑΡΧΕΙΟ...]"
+
 #: ../sendto/nautilus-sendto-plugin.c:168
 msgid "Programming error: could not find the device in the list"
 msgstr "Σφάλμα προγραμματισμού: αδυναμία εντοπισμού της συσκευής στη λίστα"
@@ -675,6 +688,9 @@
 msgid "Send files via Bluetooth"
 msgstr "Αποστολή αρχείων μέσω Bluetooth"
 
+#~ msgid "%d KB/s"
+#~ msgstr "%d KB/δευτ."
+
 #~ msgid "Remove '%s' from the list of devices?"
 #~ msgstr "Να απομακρυνθεί το «%s» από τη λίστα των συσκευών;"
 
diff -Nru gnome-bluetooth-3.4.1/wizard/main.c gnome-bluetooth-3.4.2/wizard/main.c
--- gnome-bluetooth-3.4.1/wizard/main.c	2012-06-12 17:25:28.000000000 +0200
+++ gnome-bluetooth-3.4.2/wizard/main.c	2012-07-02 12:17:07.000000000 +0200
@@ -261,7 +261,7 @@
 	invocation = g_object_get_data (G_OBJECT (button), "invocation");
 	gtk_widget_set_sensitive (does_not_match_button, FALSE);
 	gtk_widget_set_sensitive (matches_button, FALSE);
-	g_dbus_method_invocation_return_value (invocation, g_variant_new ("(s)", ""));
+	g_dbus_method_invocation_return_value (invocation, NULL);
 
 	g_object_set_data (G_OBJECT(does_not_match_button), "invocation", NULL);
 	g_object_set_data (G_OBJECT(matches_button), "invocation", NULL);
 ChangeLog                                         |  114 ++++++++++
 NEWS                                              |   12 +
 configure                                         |   20 -
 configure.ac                                      |    2 
 docs/reference/libgnome-bluetooth/html/ch01.html  |    2 
 docs/reference/libgnome-bluetooth/html/index.html |    2 
 docs/reference/libgnome-bluetooth/version.xml     |    2 
 lib/bluetooth-agent.c                             |    5 
 lib/bluetooth-client-glue.c                       |   80 +++----
 lib/bluetooth-client-glue.h                       |   18 -
 lib/bluetooth-client.c                            |   20 +
 lib/bluetooth-client.xml                          |    4 
 po/as.po                                          |  181 ++++++++--------
 po/el.po                                          |  240 +++++++++++-----------
 14 files changed, 432 insertions(+), 270 deletions(-)

--- End Message ---
--- Begin Message ---
On 10/07/12 22:25, Michael Biebl wrote:
Package: release.debian.org
Severity: normal
User: release.debian.org@packages.debian.org
Usertags: unblock

Please unblock package gnome-bluetooth

3.4.1-2 already had an freeze-exception, as it fixes an RC bug.
The latest upstream version 3.4.2 includes all the patches we had
applied to 3.4.1 and adds a few bug fixes on top. Instead of
cherry-picking more upstream patches, I decided to just upload 3.4.2.

Included is the full debdiff between 3.4.1-2 and 3.4.2-1.
I've also attached a diffstat of 3.4.1 with all patches applied
against 3.4.2.

Cheers,
Michael

unblock gnome-bluetooth/3.4.2-1


Unblocked. (PS: We will prefer targeted fixes next time).

Regards,

diff -Nru gnome-bluetooth-3.4.1/lib/bluetooth-client-glue.c gnome-bluetooth-3.4.2/lib/bluetooth-client-glue.c
--- gnome-bluetooth-3.4.1/lib/bluetooth-client-glue.c	2012-06-12 19:12:39.000000000 +0200
+++ gnome-bluetooth-3.4.2/lib/bluetooth-client-glue.c	2012-07-02 12:08:30.000000000 +0200
@@ -1,5 +1,5 @@
 /*
- * Generated by gdbus-codegen 2.33.1. DO NOT EDIT.
+ * Generated by gdbus-codegen 2.33.2. DO NOT EDIT.
  *
  * The license of this code is the same as for the source it was derived from.
  */
@@ -187,40 +187,40 @@
   FALSE
 };
 
-static const _ExtendedGDBusArgInfo _manager_method_info_list_adapters_OUT_ARG_unnamed_arg0 =
+static const _ExtendedGDBusArgInfo _manager_method_info_get_properties_OUT_ARG_unnamed_arg0 =
 {
   {
     -1,
     (gchar *) "unnamed_arg0",
-    (gchar *) "ao",
+    (gchar *) "a{sv}",
     NULL
   },
   FALSE
 };
 
-static const _ExtendedGDBusArgInfo * const _manager_method_info_list_adapters_OUT_ARG_pointers[] =
+static const _ExtendedGDBusArgInfo * const _manager_method_info_get_properties_OUT_ARG_pointers[] =
 {
-  &_manager_method_info_list_adapters_OUT_ARG_unnamed_arg0,
+  &_manager_method_info_get_properties_OUT_ARG_unnamed_arg0,
   NULL
 };
 
-static const _ExtendedGDBusMethodInfo _manager_method_info_list_adapters =
+static const _ExtendedGDBusMethodInfo _manager_method_info_get_properties =
 {
   {
     -1,
-    (gchar *) "ListAdapters",
+    (gchar *) "GetProperties",
     NULL,
-    (GDBusArgInfo **) &_manager_method_info_list_adapters_OUT_ARG_pointers,
+    (GDBusArgInfo **) &_manager_method_info_get_properties_OUT_ARG_pointers,
     NULL
   },
-  "handle-list-adapters",
+  "handle-get-properties",
   FALSE
 };
 
 static const _ExtendedGDBusMethodInfo * const _manager_method_info_pointers[] =
 {
   &_manager_method_info_default_adapter,
-  &_manager_method_info_list_adapters,
+  &_manager_method_info_get_properties,
   NULL
 };
 
@@ -371,7 +371,7 @@
  * ManagerIface:
  * @parent_iface: The parent interface.
  * @handle_default_adapter: Handler for the #Manager::handle-default-adapter signal.
  * @handle_list_adapters: Handler for the #Manager::handle-list-adapters signal.
  * @adapter_added: Handler for the #Manager::adapter-added signal.
  * @adapter_removed: Handler for the #Manager::adapter-removed signal.
  * @default_adapter_changed: Handler for the #Manager::default-adapter-changed signal.
@@ -406,20 +406,20 @@
     G_TYPE_DBUS_METHOD_INVOCATION);
 
   /**
-   * Manager::handle-list-adapters:
+   * Manager::handle-get-properties:
    * @object: A #Manager.
    * @invocation: A #GDBusMethodInvocation.
    *
    * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-bluez-Manager.ListAdapters">ListAdapters()</link> D-Bus method.
    *
    * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call manager_complete_list_adapters() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
    *
    * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
    */
-  g_signal_new ("handle-list-adapters",
+  g_signal_new ("handle-get-properties",
     G_TYPE_FROM_INTERFACE (iface),
     G_SIGNAL_RUN_LAST,
-    G_STRUCT_OFFSET (ManagerIface, handle_list_adapters),
+    G_STRUCT_OFFSET (ManagerIface, handle_get_properties),
     g_signal_accumulator_true_handled,
     NULL,
     g_cclosure_marshal_generic,
@@ -634,27 +634,27 @@
 }
 
 /**
- * manager_call_list_adapters:
+ * manager_call_get_properties:
  * @proxy: A #ManagerProxy.
  * @cancellable: (allow-none): A #GCancellable or %NULL.
  * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
  * @user_data: User data to pass to @callback.
  *
  * Asynchronously invokes the <link linkend="gdbus-method-org-bluez-Manager.ListAdapters">ListAdapters()</link> D-Bus method on @proxy.
  * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
  * You can then call manager_call_list_adapters_finish() to get the result of the operation.
  *
  * See manager_call_list_adapters_sync() for the synchronous, blocking version of this method.
  */
 void
-manager_call_list_adapters (
+manager_call_get_properties (
     Manager *proxy,
     GCancellable *cancellable,
     GAsyncReadyCallback callback,
     gpointer user_data)
 {
   g_dbus_proxy_call (G_DBUS_PROXY (proxy),
-    "ListAdapters",
+    "GetProperties",
     g_variant_new ("()"),
     G_DBUS_CALL_FLAGS_NONE,
     -1,
@@ -664,20 +664,20 @@
 }
 
 /**
- * manager_call_list_adapters_finish:
+ * manager_call_get_properties_finish:
  * @proxy: A #ManagerProxy.
  * @out_unnamed_arg0: (out): Return location for return parameter or %NULL to ignore.
  * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to manager_call_list_adapters().
  * @error: Return location for error or %NULL.
  *
  * Finishes an operation started with manager_call_list_adapters().
  *
  * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
  */
 gboolean
-manager_call_list_adapters_finish (
+manager_call_get_properties_finish (
     Manager *proxy,
-    gchar ***out_unnamed_arg0,
+    GVariant **out_unnamed_arg0,
     GAsyncResult *res,
     GError **error)
 {
@@ -686,7 +686,7 @@
   if (_ret == NULL)
     goto _out;
   g_variant_get (_ret,
-                 "(^ao)",
+                 "(@a{sv})",
                  out_unnamed_arg0);
   g_variant_unref (_ret);
 _out:
@@ -694,28 +694,28 @@
 }
 
 /**
- * manager_call_list_adapters_sync:
+ * manager_call_get_properties_sync:
  * @proxy: A #ManagerProxy.
  * @out_unnamed_arg0: (out): Return location for return parameter or %NULL to ignore.
  * @cancellable: (allow-none): A #GCancellable or %NULL.
  * @error: Return location for error or %NULL.
  *
  * Synchronously invokes the <link linkend="gdbus-method-org-bluez-Manager.ListAdapters">ListAdapters()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
  *
  * See manager_call_list_adapters() for the asynchronous version of this method.
  *
  * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
  */
 gboolean
-manager_call_list_adapters_sync (
+manager_call_get_properties_sync (
     Manager *proxy,
-    gchar ***out_unnamed_arg0,
+    GVariant **out_unnamed_arg0,
     GCancellable *cancellable,
     GError **error)
 {
   GVariant *_ret;
   _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
-    "ListAdapters",
+    "GetProperties",
     g_variant_new ("()"),
     G_DBUS_CALL_FLAGS_NONE,
     -1,
@@ -724,7 +724,7 @@
   if (_ret == NULL)
     goto _out;
   g_variant_get (_ret,
-                 "(^ao)",
+                 "(@a{sv})",
                  out_unnamed_arg0);
   g_variant_unref (_ret);
 _out:
@@ -753,23 +753,23 @@
 }
 
 /**
- * manager_complete_list_adapters:
+ * manager_complete_get_properties:
  * @object: A #Manager.
  * @invocation: (transfer full): A #GDBusMethodInvocation.
  * @unnamed_arg0: Parameter to return.
  *
  * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-bluez-Manager.ListAdapters">ListAdapters()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
  *
  * This method will free @invocation, you cannot use it afterwards.
  */
 void
-manager_complete_list_adapters (
+manager_complete_get_properties (
     Manager *object,
     GDBusMethodInvocation *invocation,
-    const gchar *const *unnamed_arg0)
+    GVariant *unnamed_arg0)
 {
   g_dbus_method_invocation_return_value (invocation,
-    g_variant_new ("(^ao)",
+    g_variant_new ("(@a{sv})",
                    unnamed_arg0));
 }
 
@@ -371,7 +371,7 @@
  * @parent_iface: The parent interface.
  * @handle_default_adapter: Handler for the #Manager::handle-default-adapter signal.
- * @handle_list_adapters: Handler for the #Manager::handle-list-adapters signal.
+ * @handle_get_properties: Handler for the #Manager::handle-get-properties signal.
  * @adapter_added: Handler for the #Manager::adapter-added signal.
  * @adapter_removed: Handler for the #Manager::adapter-removed signal.
@@ -406,20 +406,20 @@
    * @invocation: A #GDBusMethodInvocation.
    *
-   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-bluez-Manager.ListAdapters">ListAdapters()</link> D-Bus method.
+   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-bluez-Manager.GetProperties">GetProperties()</link> D-Bus method.
    *
@@ -406,20 +406,20 @@
    *
-   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call manager_complete_list_adapters() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
+   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call manager_complete_get_properties() or e.g. g_dbus_method_invocation_return_error() on it) and no order signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
    *
    * Returns: %TRUE if the invocation was handled, %FALSE to let other signal handlers run.
@@ -634,27 +634,27 @@
  * @user_data: User data to pass to @callback.
  *
- * Asynchronously invokes the <link linkend="gdbus-method-org-bluez-Manager.ListAdapters">ListAdapters()</link> D-Bus method on @proxy.
+ * Asynchronously invokes the <link linkend="gdbus-method-org-bluez-Manager.GetProperties">GetProperties()</link> D-Bus method on @proxy.
  * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
@@ -634,27 +634,27 @@
  * When the operation is finished, @callback will be invoked in the <link linkend="g-main-context-push-thread-default">thread-default main loop</link> of the thread you are calling this method from.
- * You can then call manager_call_list_adapters_finish() to get the result of the operation.
+ * You can then call manager_call_get_properties_finish() to get the result of the operation.
  *
@@ -634,27 +634,27 @@
  *
- * See manager_call_list_adapters_sync() for the synchronous, blocking version of this method.
+ * See manager_call_get_properties_sync() for the synchronous, blocking version of this method.
  */
 void
@@ -664,20 +664,20 @@
  * @proxy: A #ManagerProxy.
  * @out_unnamed_arg0: (out): Return location for return parameter or %NULL to ignore.
- * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to manager_call_list_adapters().
+ * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to manager_call_get_properties().
  * @error: Return location for error or %NULL.
  *
@@ -664,20 +664,20 @@
  * @error: Return location for error or %NULL.
  *
- * Finishes an operation started with manager_call_list_adapters().
+ * Finishes an operation started with manager_call_get_properties().
  *
  * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
@@ -694,28 +694,28 @@
  * @error: Return location for error or %NULL.
  *
- * Synchronously invokes the <link linkend="gdbus-method-org-bluez-Manager.ListAdapters">ListAdapters()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
+ * Synchronously invokes the <link linkend="gdbus-method-org-bluez-Manager.GetProperties">GetProperties()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
  *
@@ -694,28 +694,28 @@
  *
- * See manager_call_list_adapters() for the asynchronous version of this method.
+ * See manager_call_get_properties() for the asynchronous version of this method.
  *
  * Returns: (skip): %TRUE if the call succeded, %FALSE if @error is set.
@@ -753,23 +753,23 @@
  * @unnamed_arg0: Parameter to return.
  *
- * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-bluez-Manager.ListAdapters">ListAdapters()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
+ * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-bluez-Manager.GetProperties">GetProperties()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
  *
  * This method will free @invocation, you cannot use it afterwards.
--
Mehdi Dogguy مهدي الدڤي
http://dogguy.org/


--- End Message ---

Reply to: